# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-07-19 14:51
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_pos', '0003_auto_20170719_1450'),
    ]

    operations = [
        migrations.AlterField(
            model_name='poshardware',
            name='pos',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='hardwares', to='codenerix_pos.POS', verbose_name='Hardware'),
        ),
    ]
