# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-07-20 15:04
from __future__ import unicode_literals

from django.db import migrations, models
import uuid


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_pos', '0005_auto_20170719_1454'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='poshardware',
            name='token',
        ),
        migrations.AddField(
            model_name='pos',
            name='cid',
            field=models.CharField(blank=True, max_length=20, null=True, verbose_name='CID'),
        ),
        migrations.AddField(
            model_name='poshardware',
            name='uuid',
            field=models.UUIDField(default=uuid.uuid4, editable=False, unique=True),
        ),
        migrations.AlterField(
            model_name='poshardware',
            name='kind',
            field=models.CharField(choices=[('T', 'Ticket'), ('D', 'DNI'), ('C', 'Cash'), ('S', 'Signature'), ('Q', 'Query')], max_length=1, verbose_name='Kind'),
        ),
    ]
