# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-07-20 15:48
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_pos', '0006_auto_20170720_1504'),
    ]

    operations = [
        migrations.AlterField(
            model_name='pos',
            name='hardware',
            field=models.ManyToManyField(blank=True, null=True, related_name='poss', to='codenerix_pos.POSHardware', verbose_name='Hardware it can use'),
        ),
        migrations.AlterField(
            model_name='poshardware',
            name='kind',
            field=models.CharField(choices=[('T', 'Ticket'), ('D', 'DNI'), ('C', 'Cash'), ('P', 'Printer'), ('S', 'Signature'), ('Q', 'Query')], max_length=1, verbose_name='Kind'),
        ),
    ]
