# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-07-20 15:53
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_pos', '0007_auto_20170720_1548'),
    ]

    operations = [
        migrations.AlterField(
            model_name='pos',
            name='cid',
            field=models.CharField(blank=True, max_length=20, null=True, unique=True, verbose_name='CID'),
        ),
    ]
