# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-07-26 16:54
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_pos', '0011_auto_20170726_1613'),
        ('codenerix_pos', '0006_auto_20170724_0832'),
    ]

    operations = [
    ]
