# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-07-27 15:46
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_pos', '0013_auto_20170726_1725'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='pos',
            name='token',
        ),
        migrations.AddField(
            model_name='pos',
            name='key',
            field=models.CharField(default='12345678901234567890123456789012', max_length=32, unique=True, verbose_name='Key'),
            preserve_default=False,
        ),
    ]
